==> msprof_analyze-1.2.2-py3-none-any.whl: profiler/advisor/analyzer/memory/memory_checker.py <==
import os
import re
import logging
import yaml

from profiler.advisor.dataset.timeline_event_dataset import ScheduleAnalysisDataset, MemCollector
from profiler.advisor.result.result import OptimizeResult
from profiler.advisor.result.item import OptimizeItem, OptimizeRecord
from profiler.cluster_analyse.common_func.file_manager import FileManager

logger = logging.getLogger()


class MemoryOpsChecker:

    def __init__(self):

        self.memory_issues = False
        self.optimization_item = []
        self.desc = ""
        self.suggestions = []
        self.memory_ops_duration_threshold = None
        self.max_mem_op_dur = 0

    def check_memory_ops(self, event_dataset: ScheduleAnalysisDataset):
        """
        :Param event_dataset: dataset of timeline event
        """
        if not hasattr(event_dataset, "memory_ops") or not getattr(event_dataset, "memory_ops") or \
                not event_dataset.memory_ops.mem_op_info:
            logger.debug("Skip slow memory ops checker, because no memory ops: %s", MemCollector.MEMORY_OP_NAME)
            return

        rule = event_dataset.memory_ops.rule
        max_dur_thres = rule.get("max_total_duration")
        raw_problem = rule.get("problem")

        for memory_op_name, memory_op_info in event_dataset.memory_ops.mem_op_info.items():
            op_dur = memory_op_info.get("total_dur")
            op_count = memory_op_info.get("count")
            if op_dur < max_dur_thres:
                continue
            if op_dur > self.max_mem_op_dur:
                self.max_mem_op_dur = op_dur

            self.memory_issues = True
            self.desc += raw_problem.format(memory_op_num=op_count, memory_op_name=memory_op_name,
                                            memory_op_dur=op_dur) + " "
            for solution in rule.get("solutions", []):
                if memory_op_name not in solution:
                    continue
                suggestion = solution.get(memory_op_name, {}).get("desc")

                self.suggestions.append(f"{suggestion} for optimize memory operator {memory_op_name}")

    def make_record(self, result: OptimizeResult):
        """
        make record for what and how to optimize
        """
        if not self.memory_issues:
            return

        self.optimization_item.append(OptimizeItem("Memory", self.desc, self.suggestions))
        for optimization in self.optimization_item:
            result.add(OptimizeRecord(optimization))

    def make_render(self, html_render, **kwargs):
        if not self.memory_issues:
            return
        priority = kwargs.get("priority")
        html_render.render_template(key="memory",
                                    template_dir="templates",
                                    template_name="memory.html",
                                    desc=self.desc,
                                    suggestions=self.suggestions,
                                    priority_background_color=priority)

==> msprof_analyze-1.2.4-py3-none-any.whl: profiler/advisor/analyzer/memory/memory_checker.py <==
import os
import re
import logging
import yaml

from profiler.advisor.dataset.timeline_event_dataset import ScheduleAnalysisDataset, MemCollector
from profiler.advisor.result.result import OptimizeResult
from profiler.advisor.result.item import OptimizeItem, OptimizeRecord
from profiler.cluster_analyse.common_func.file_manager import FileManager

logger = logging.getLogger()


class MemoryOpsChecker:

    def __init__(self):

        self.memory_issues = False
        self.optimization_item = []
        self.desc = ""
        self.suggestions = []
        self.memory_ops_duration_threshold = None
        self.max_mem_op_dur = 0

    def check_memory_ops(self, event_dataset: ScheduleAnalysisDataset):
        """
        :Param event_dataset: dataset of timeline event
        """
        if not hasattr(event_dataset, "memory_ops") or not getattr(event_dataset, "memory_ops") or \
                not event_dataset.memory_ops.mem_op_info:
            logger.debug("Skip slow memory ops checker, because no memory ops: %s", MemCollector.MEMORY_OP_NAME)
            return

        rule = event_dataset.memory_ops.rule
        max_dur_thres = rule.get("max_total_duration")
        raw_problem = rule.get("problem")

        for memory_op_name, memory_op_info in event_dataset.memory_ops.mem_op_info.items():
            op_dur = memory_op_info.get("total_dur")
            op_count = memory_op_info.get("count")
            if op_dur < max_dur_thres:
                continue
            if op_dur > self.max_mem_op_dur:
                self.max_mem_op_dur = op_dur

            self.memory_issues = True
            self.desc += raw_problem.format(memory_op_num=op_count, memory_op_name=memory_op_name,
                                            memory_op_dur=op_dur) + " "
            for solution in rule.get("solutions", []):
                if memory_op_name not in solution:
                    continue
                suggestions = solution.get(memory_op_name, {}).get("desc")
                for suggestion in suggestions:
                    self.suggestions.append(f"For {memory_op_name}: {suggestion}")

    def make_record(self, result: OptimizeResult):
        """
        make record for what and how to optimize
        """
        if not self.memory_issues:
            return

        self.optimization_item.append(OptimizeItem("Memory", self.desc, self.suggestions))
        for optimization in self.optimization_item:
            result.add(OptimizeRecord(optimization))

    def make_render(self, html_render, **kwargs):
        if not self.memory_issues:
            return
        priority = kwargs.get("priority")
        html_render.render_template(key="memory",
                                    template_dir="templates",
                                    template_name="memory.html",
                                    desc=self.desc,
                                    suggestions=self.suggestions,
                                    priority_background_color=priority)
